Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(486)

Unified Diff: content/browser/frame_host/navigation_entry_impl.h

Issue 2174293002: NonValidatingReload: Monitor reload operations in NavigationControllerImpl (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: [rebase] Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/navigation_entry_impl.h
diff --git a/content/browser/frame_host/navigation_entry_impl.h b/content/browser/frame_host/navigation_entry_impl.h
index fa2c88e9614ec8db0e57e2a3d5ee221c228e1203..873fed693d524134a7c52f00b3547dc376f8c29e 100644
--- a/content/browser/frame_host/navigation_entry_impl.h
+++ b/content/browser/frame_host/navigation_entry_impl.h
@@ -20,6 +20,7 @@
#include "content/public/browser/favicon_status.h"
#include "content/public/browser/global_request_id.h"
#include "content/public/browser/navigation_entry.h"
+#include "content/public/browser/reload_type.h"
#include "content/public/browser/restore_type.h"
#include "content/public/browser/ssl_status.h"
#include "content/public/common/page_state.h"
@@ -313,7 +314,7 @@ class CONTENT_EXPORT NavigationEntryImpl
}
// The RestoreType for this entry. This is set if the entry was retored. This
// is set to RESTORE_NONE once the entry is loaded.
void set_restore_type(RestoreType type) {
restore_type_ = type;
}
@@ -321,6 +322,12 @@ class CONTENT_EXPORT NavigationEntryImpl
return restore_type_;
}
+ // The ReloadType for this entry. This is set when a reload is requested.
+ // This is set to ReloadType::NONE if the entry isn't for a reload, or once
+ // the entry is loaded.
+ void set_reload_type(ReloadType type) { reload_type_ = type; }
+ ReloadType reload_type() const { return reload_type_; }
+
void set_transferred_global_request_id(
const GlobalRequestID& transferred_global_request_id) {
transferred_global_request_id_ = transferred_global_request_id;
@@ -515,6 +522,10 @@ class CONTENT_EXPORT NavigationEntryImpl
bool has_user_gesture_;
#endif
+ // Used to store ReloadType for the entry. This is ReloadType::NONE for
+ // non-reload navigations. Reset at commit and not persisted.
+ ReloadType reload_type_;
+
// Used to store extra data to support browser features. This member is not
// persisted, unless specific data is taken out/put back in at save/restore
// time (see TabNavigation for an example of this).
@@ -313,7 +314,7 @@ class CONTENT_EXPORT NavigationEntryImpl
}
// The RestoreType for this entry. This is set if the entry was retored. This
- // is set to RESTORE_NONE once the entry is loaded.
+ // is set to RestoreType::NONE once the entry is loaded.
void set_restore_type(RestoreType type) {
restore_type_ = type;

Powered by Google App Engine
This is Rietveld 408576698